@@ -22,6 +22,10 @@ def test_webapp():
 
     pars = cw.get_defaults()
     output = cw.run_sim(sim_pars=pars['sim_pars'], epi_pars=pars['epi_pars'])
+    if output['err']:
+        errormsg = 'Webapp encountered an error:\n'
+        errormsg += output['err']
+        raise Exception(errormsg)
 
     return output
 
